-
Notifications
You must be signed in to change notification settings - Fork 6
Commit
This commit does not belong to any branch on this repository, and may belong to a fork outside of the repository.
#357 added numpy 1.23.5 to 2022b - ok
- Loading branch information
1 parent
cd70167
commit 69666f5
Showing
3 changed files
with
91 additions
and
18 deletions.
There are no files selected for viewing
43 changes: 43 additions & 0 deletions
43
357_Synthcity/2022b_version/numpy-1.20.3_fix-fortran-compiler-error.patch
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
Original file line number | Diff line number | Diff line change |
---|---|---|
@@ -0,0 +1,43 @@ | ||
Using Fortran compilers which differ "too much" from GCC fails building NumPy with something like | ||
> A valid Fortran version was not found in this string: [...] | ||
|
||
See https://github.com/easybuilders/easybuild-easyblocks/issues/2518 and https://github.com/numpy/numpy/pull/26502 | ||
|
||
Fix by converting the hard error into a warning as the issue would be handled later if required. | ||
E.g. for building NumPy we don't need a Fortran compiler at all. | ||
|
||
Author: Alexander Grund (TU Dresden) | ||
|
||
diff -Nru numpy-1.22.3.orig/numpy/distutils/tests/test_system_info.py numpy-1.22.3/numpy/distutils/tests/test_system_info.py | ||
--- numpy-1.22.3.orig/numpy/distutils/tests/test_system_info.py 2022-05-19 13:52:55.000000000 +0100 | ||
+++ numpy-1.22.3/numpy/distutils/tests/test_system_info.py 2022-05-19 13:54:24.000000000 +0100 | ||
@@ -258,7 +258,7 @@ | ||
|
||
@pytest.mark.xfail(HAS_MKL, reason=("`[DEFAULT]` override doesn't work if " | ||
"numpy is built with MKL support")) | ||
- def test_overrides(self): | ||
+ def ignored_test_overrides(self): | ||
previousDir = os.getcwd() | ||
cfg = os.path.join(self._dir1, 'site.cfg') | ||
shutil.copy(self._sitecfg, cfg) |
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
diff --git a/numpy/distutils/fcompiler/gnu.py b/numpy/distutils/fcompiler/gnu.py | ||
index eac4cbb477..8a1043fe26 100644 | ||
--- a/numpy/distutils/fcompiler/gnu.py | ||
+++ b/numpy/distutils/fcompiler/gnu.py | ||
@@ -8,6 +8,7 @@ import hashlib | ||
import base64 | ||
import subprocess | ||
from subprocess import Popen, PIPE, STDOUT | ||
+from distutils import log | ||
from numpy.distutils.exec_command import filepath_from_subprocess_output | ||
from numpy.distutils.fcompiler import FCompiler | ||
from distutils.version import LooseVersion | ||
@@ -69,9 +70,9 @@ class GnuFCompiler(FCompiler): | ||
# from the version string | ||
return ('gfortran', v) | ||
|
||
- # If still nothing, raise an error to make the problem easy to find. | ||
- err = 'A valid Fortran version was not found in this string:\n' | ||
- raise ValueError(err + version_string) | ||
+ # If still nothing, warn to make the problem easy to find. | ||
+ log.warn('A valid Fortran version was not found in this string:\n' | ||
+ + version_string) | ||
|
||
def version_match(self, version_string): | ||
v = self.gnu_version_match(version_string) | ||
@@ -539,7 +540,6 @@ def _can_target(cmd, arch): | ||
|
||
|
||
if __name__ == '__main__': | ||
- from distutils import log | ||
from numpy.distutils import customized_fcompiler | ||
log.set_verbosity(2) | ||
|
16 changes: 16 additions & 0 deletions
16
357_Synthcity/2022b_version/numpy-1.22.3_disable-broken-override-test.patch
This file contains bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
Original file line number | Diff line number | Diff line change |
---|---|---|
@@ -0,0 +1,16 @@ | ||
skip broken test, see https://github.com/numpy/numpy/issues/16769 | ||
author: Kenneth Hoste (HPC-UGent) | ||
updated for version 1.22.3 by Jasper Grimm (UoY) | ||
----------------------------------------------------------------- | ||